import { aws_eks as eks } from 'aws-cdk-lib';
import { Construct } from 'constructs';
export interface VpcCniAddonProps extends EksManagedAddonProps {
    readonly addonVersion?: VpcCniAddonVersion;
}
interface EksManagedAddonProps {
    readonly cluster: eks.Cluster;
    readonly addonVersion?: AddonVersion;
    readonly resolveConflicts?: boolean;
    readonly namespace?: string;
}
declare abstract class AddonVersion {
    readonly version: string;
    static of(version: string): void;
    /**
     * @param version add-on version
     */
    protected constructor(version: string);
}
/**
 * vpc-cni add-on versions
 */
export declare class VpcCniAddonVersion extends AddonVersion {
    /**
     * vpc-cni version 1.6.3
     */
    static readonly V1_6_3: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.7.5
     */
    static readonly V1_7_5: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.7.6
     */
    static readonly V1_7_6: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.7.9
     */
    static readonly V1_7_9: VpcCniAddonVersion;
    /**
     * Custom add-on version
     * @param version custom add-on version
     */
    static of(version: string): VpcCniAddonVersion;
}
interface EksManagedAddonAbstractProps {
    readonly cluster: eks.Cluster;
    readonly addonName: string;
    readonly addonVersion?: AddonVersion;
    readonly resolveConflicts?: boolean;
    readonly serviceAccountName?: string;
    readonly awsManagedPolicyName?: string;
    readonly namespace?: string;
}
declare abstract class EksManagedAddonAbstract extends eks.CfnAddon {
    protected constructor(scope: Construct, id: string, props: EksManagedAddonAbstractProps);
}
export declare class VpcCniAddon extends EksManagedAddonAbstract {
    constructor(scope: Construct, id: string, props: VpcCniAddonProps);
}
export {};
